==> qttools-6.10.1-r1-3.gpkg.tar: image/usr/src/debug/dev-qt/qttools-6.10.1-r1/qttools-everywhere-src-6.10.1_build/src/designer/src/components/lib/.qt/rcc/qrc_formeditor1.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // defaultbrushes.xml
  0x0,0x0,0x2,0xcd,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x3,0x33,0x1d,0x16,0x0,0x66,0x16,0x45,0x1f,0x20,0x91,0x75,
  0xff,0xb7,0x22,0x6c,0xf7,0x64,0xf5,0xb0,0x51,0x0,0x3f,0xac,0x39,0x6,0x82,0xbe,
  0x3a,0xb0,0x1f,0xec,0x16,0x0,0xd,0x0,0xb8,0x4,0xa,0x2,0x3a,0x0,0x3a,0x0,
  0x3f,0x0,0x96,0x35,0x48,0x64,0x47,0xab,0x22,0xbf,0x2f,0xcb,0x28,0x8f,0xd1,0xfe,
  0xbd,0xec,0xb8,0xf4,0x32,0x72,0x23,0x9a,0x4f,0xe5,0xa2,0x55,0x9f,0x9b,0x6b,0x19,
  0x63,0x80,0x2,0x6b,0x16,0xa4,0xef,0x43,0xab,0x6e,0x61,0xca,0x68,0x95,0xf7,0x92,
  0xd,0xed,0xe3,0x63,0x80,0x82,0xbd,0x65,0x2f,0x2d,0x79,0x1,0xef,0x29,0xc4,0xf7,
  0x63,0xce,0x45,0xad,0x62,0xeb,0x9a,0xcc,0xba,0xce,0xa,0x1f,0x93,0xb6,0x5e,0xec,
  0xaa,0xd7,0x3e,0x56,0xc6,0xa1,0xc4,0xdc,0x50,0x23,0x16,0xbc,0xef,0xb,0x69,0xd5,
  0x63,0xb5,0xfc,0x32,0x95,0xb1,0x6b,0x85,0xac,0x41,0x91,0x9e,0xb5,0x6b,0x73,0x37,
  0x4f,0xab,0x34,0xb7,0xf9,0x6,0x8f,0xdb,0x53,0xbe,0x58,0x31,0x4d,0x94,0xe5,0xe4,
  0x9b,0x80,0x8,0x3,0x2,0x35,0x98,0x26,0xe7,0x24,0x81,0x20,0x8a,0xdc,0x3,0x11,
  0x1e,0x28,0x9a,0x28,0xa8,0xf2,0x37,0xf5,0x3c,0xd0,0x43,0xd9,0xd2,0x47,0x38,0xcf,
  0x81,0x1e,0x6a,0x72,0x93,0x24,0x88,0x4,0x1,0xc7,0x71,0x5e,0xe1,0x97,0x29,0xa1,
  0x7f,0x53,0xe2,0xdb,0x9,0xce,0xcb,0xd4,0x39,0xbf,0xf9,0x95,0x56,0x26,0xbe,0xf9,
  0xd2,0x53,0xd8,0x42,0x79,0x3,0x7f,0x89,0x72,0x56,0x8,0xe4,0x29,0x91,0x28,0x89,
  0xf2,0x5,0x89,0x9c,0x65,0xe5,0xac,0xe,0x47,0x49,0x14,0xe5,0xa2,0x88,0xf2,0x4c,
  0xd7,0x6,0xe4,0x8,0x52,0x5f,0x7a,0x68,0x2f,0x9b,0xa6,0x99,0xc,0xeb,0x64,0x72,
  0x80,0x99,0xa8,0x91,0x41,0x43,0x43,0x23,0x29,0x48,0x4a,0xa5,0xe,0x40,0x44,0x20,
  0xc6,0xc,0xd2,0xd4,0x36,0x52,0x20,0x48,0x8,0x24,0xa0,0x8,0x20,0x88,0x60,0x8c,
  0x60,0x88,0x20,0x61,0x8,0x46,0x10,0x82,0x11,0x8,0x62,0x8,0x5a,0x88,0xa3,0x7b,
  0xfc,0x33,0xc6,0x5,0x3d,0xe,0x89,0xe2,0x57,0xbe,0x31,0xa1,0xba,0x7e,0x5f,0xd,
  0xf1,0x6b,0x83,0x78,0xc8,0x5d,0x42,0x2c,0x53,0xf5,0x37,0x46,0x44,0xf0,0xaa,0x59,
  0x2f,0xe0,0x54,0x5,0x78,0x24,0xa,0x7c,0xb7,0xd6,0x59,0x8e,0x37,0xcf,0xbd,0x27,
  0x30,0x56,0x1c,0x62,0xb2,0xe4,0x74,0x94,0xa8,0xce,0x73,0xb8,0xfc,0x38,0x12,0x92,
  0x7c,0xb8,0x70,0x46,0x58,0xf,0x67,0x3a,0xd4,0x8,0x8d,0xae,0x43,0x2,0xc1,0xa6,
  0x51,0x93,0x42,0x71,0x78,0x28,0x6c,0x19,0x9e,0xa0,0xd4,0xdd,0x7,0x37,0xc6,0xba,
  0x10,0xb,0x63,0xad,0x7a,0xd5,0x22,0x14,0xa1,0xa8,0x91,0xc4,0x11,0xa9,0xbd,0x9,
  0x11,0x85,0xdd,0xb5,0x6d,0x93,0x84,0x52,0x4,0x51,0x12,0xcd,0xed,0x94,0x4,0xfd,
  0xe6,0x6,0x13,0x7f,0x3,0xe9,0x1f,0xbd,0x7d,0xa5,0xc3,0x3c,0xe,0xc1,0x72,0x48,
  0x5b,0x94,0x25,0x12,0x60,0x1d,0xa3,0xf9,0xef,0x45,0xe9,0xe8,0x36,0xc8,0x1a,0xdc,
  0x53,0xd7,0x37,0x80,0xd6,0x13,0x61,0x6a,0x52,0x22,0xf5,0x26,0x28,0xd6,0x97,0x88,
  0xef,0x14,0x92,0xb3,0x89,0x71,0x6,0xb9,0xc5,0x73,0x30,0xfb,0x9b,0xb2,0x15,0xa4,
  0x58,0xb,0x28,0x2b,0xea,0x19,0x4c,0xde,0x17,0x32,0xd2,0x46,0xd4,0x38,0xf2,0xc,
  0x51,0x8a,0x26,0xf4,0x8e,0x83,0x4c,0xd4,0x1e,0x79,0x7e,0x94,0x22,0xf,0xbd,0xd3,
  0x20,0x13,0xb1,0x47,0x9e,0x1f,0xa5,0xc8,0x43,0xef,0x30,0xc8,0x44,0xef,0x91,0x47,
  0x8f,0x52,0xc4,0x82,0xca,0x91,0xe4,0x31,0x51,0x5d,0x30,0x33,0xe7,0x48,0xef,0x21,
  0x98,0xdc,0x16,0xc6,0xbc,0x4e,0x19,0x60,0xac,0x83,0x2c,0x73,0x7,0x57,0x18,0x9a,
  0x2b,0x21,0x50,0x63,0x2c,0x1c,0x64,0x8c,0x4a,0x54,0x75,0x22,0x70,0x1b,0x65,0x9c,
  0xbe,0x8b,0x95,0x98,0x93,0x91,0x57,0x24,0x7f,0xdb,0xc1,0xf,0xe5,0x4e,0x49,0xdf,
  0xe7,0x2b,0x24,0xd2,0x90,0x36,0x9c,0x22,0xd6,0xd1,0x29,0xa5,0xfe,0xee,0x97,0x3a,
  0xa5,0x9e,0x84,0xac,0x76,0xec,0x34,0x76,0x7d,0x96,0x3c,0xa3,0x2d,0xc3,0x6,0xde,
  0xa8,0x8a,0xc9,0xc2,0x70,0xe4,0x6e,0xf3,0x7d,0x3d,0x3f,0x82,0xd2,0x86,0x95,0x49,
  0x5c,0x88,0x45,0xc8,0xe2,0x3a,0x86,0x52,0x2d,0x20,0x30,0x53,0x3e,0xe4,0x66,0x32,
  0x5f,0xd2,0x9,0x1e,0x22,0xde,0xc3,0x11,0x51,0x43,0xe2,0x2a,
  
};

static const unsigned char qt_resource_name[] = {
  // qt-project.org
  0x0,0xe,
  0x5,0x28,0x6c,0x87,
  0x0,0x71,
  0x0,0x74,0x0,0x2d,0x0,0x70,0x0,0x72,0x0,0x6f,0x0,0x6a,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x2e,0x0,0x6f,0x0,0x72,0x0,0x67,
    // brushes
  0x0,0x7,
  0x9,0x9c,0x9e,0x3,
  0x0,0x62,
  0x0,0x72,0x0,0x75,0x0,0x73,0x0,0x68,0x0,0x65,0x0,0x73,
    // defaultbrushes.xml
  0x0,0x12,
  0x3,0x3a,0x45,0x3c,
  0x0,0x64,
  0x0,0x65,0x0,0x66,0x0,0x61,0x0,0x75,0x0,0x6c,0x0,0x74,0x0,0x62,0x0,0x72,0x0,0x75,0x0,0x73,0x0,0x68,0x0,0x65,0x0,0x73,0x0,0x2e,0x0,0x78,0x0,0x6d,
  0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/brushes
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/brushes/defaultbrushes.xml
  0x0,0x0,0x0,0x36,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9a,0x7e,0xef,0x8d,0xe0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_formeditor1)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_formeditor1)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_formeditor1)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_formeditor1)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_formeditor1)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_formeditor1)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> qttools-6.10.2-1.gpkg.tar: image/usr/src/debug/dev-qt/qttools-6.10.2/qttools-everywhere-src-6.10.2_build/src/designer/src/components/lib/.qt/rcc/qrc_formeditor1.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // defaultbrushes.xml
  0x0,0x0,0x2,0xcd,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x3,0x33,0x1d,0x16,0x0,0x66,0x16,0x45,0x1f,0x20,0x91,0x75,
  0xff,0xb7,0x22,0x6c,0xf7,0x64,0xf5,0xb0,0x51,0x0,0x3f,0xac,0x39,0x6,0x82,0xbe,
  0x3a,0xb0,0x1f,0xec,0x16,0x0,0xd,0x0,0xb8,0x4,0xa,0x2,0x3a,0x0,0x3a,0x0,
  0x3f,0x0,0x96,0x35,0x48,0x64,0x47,0xab,0x22,0xbf,0x2f,0xcb,0x28,0x8f,0xd1,0xfe,
  0xbd,0xec,0xb8,0xf4,0x32,0x72,0x23,0x9a,0x4f,0xe5,0xa2,0x55,0x9f,0x9b,0x6b,0x19,
  0x63,0x80,0x2,0x6b,0x16,0xa4,0xef,0x43,0xab,0x6e,0x61,0xca,0x68,0x95,0xf7,0x92,
  0xd,0xed,0xe3,0x63,0x80,0x82,0xbd,0x65,0x2f,0x2d,0x79,0x1,0xef,0x29,0xc4,0xf7,
  0x63,0xce,0x45,0xad,0x62,0xeb,0x9a,0xcc,0xba,0xce,0xa,0x1f,0x93,0xb6,0x5e,0xec,
  0xaa,0xd7,0x3e,0x56,0xc6,0xa1,0xc4,0xdc,0x50,0x23,0x16,0xbc,0xef,0xb,0x69,0xd5,
  0x63,0xb5,0xfc,0x32,0x95,0xb1,0x6b,0x85,0xac,0x41,0x91,0x9e,0xb5,0x6b,0x73,0x37,
  0x4f,0xab,0x34,0xb7,0xf9,0x6,0x8f,0xdb,0x53,0xbe,0x58,0x31,0x4d,0x94,0xe5,0xe4,
  0x9b,0x80,0x8,0x3,0x2,0x35,0x98,0x26,0xe7,0x24,0x81,0x20,0x8a,0xdc,0x3,0x11,
  0x1e,0x28,0x9a,0x28,0xa8,0xf2,0x37,0xf5,0x3c,0xd0,0x43,0xd9,0xd2,0x47,0x38,0xcf,
  0x81,0x1e,0x6a,0x72,0x93,0x24,0x88,0x4,0x1,0xc7,0x71,0x5e,0xe1,0x97,0x29,0xa1,
  0x7f,0x53,0xe2,0xdb,0x9,0xce,0xcb,0xd4,0x39,0xbf,0xf9,0x95,0x56,0x26,0xbe,0xf9,
  0xd2,0x53,0xd8,0x42,0x79,0x3,0x7f,0x89,0x72,0x56,0x8,0xe4,0x29,0x91,0x28,0x89,
  0xf2,0x5,0x89,0x9c,0x65,0xe5,0xac,0xe,0x47,0x49,0x14,0xe5,0xa2,0x88,0xf2,0x4c,
  0xd7,0x6,0xe4,0x8,0x52,0x5f,0x7a,0x68,0x2f,0x9b,0xa6,0x99,0xc,0xeb,0x64,0x72,
  0x80,0x99,0xa8,0x91,0x41,0x43,0x43,0x23,0x29,0x48,0x4a,0xa5,0xe,0x40,0x44,0x20,
  0xc6,0xc,0xd2,0xd4,0x36,0x52,0x20,0x48,0x8,0x24,0xa0,0x8,0x20,0x88,0x60,0x8c,
  0x60,0x88,0x20,0x61,0x8,0x46,0x10,0x82,0x11,0x8,0x62,0x8,0x5a,0x88,0xa3,0x7b,
  0xfc,0x33,0xc6,0x5,0x3d,0xe,0x89,0xe2,0x57,0xbe,0x31,0xa1,0xba,0x7e,0x5f,0xd,
  0xf1,0x6b,0x83,0x78,0xc8,0x5d,0x42,0x2c,0x53,0xf5,0x37,0x46,0x44,0xf0,0xaa,0x59,
  0x2f,0xe0,0x54,0x5,0x78,0x24,0xa,0x7c,0xb7,0xd6,0x59,0x8e,0x37,0xcf,0xbd,0x27,
  0x30,0x56,0x1c,0x62,0xb2,0xe4,0x74,0x94,0xa8,0xce,0x73,0xb8,0xfc,0x38,0x12,0x92,
  0x7c,0xb8,0x70,0x46,0x58,0xf,0x67,0x3a,0xd4,0x8,0x8d,0xae,0x43,0x2,0xc1,0xa6,
  0x51,0x93,0x42,0x71,0x78,0x28,0x6c,0x19,0x9e,0xa0,0xd4,0xdd,0x7,0x37,0xc6,0xba,
  0x10,0xb,0x63,0xad,0x7a,0xd5,0x22,0x14,0xa1,0xa8,0x91,0xc4,0x11,0xa9,0xbd,0x9,
  0x11,0x85,0xdd,0xb5,0x6d,0x93,0x84,0x52,0x4,0x51,0x12,0xcd,0xed,0x94,0x4,0xfd,
  0xe6,0x6,0x13,0x7f,0x3,0xe9,0x1f,0xbd,0x7d,0xa5,0xc3,0x3c,0xe,0xc1,0x72,0x48,
  0x5b,0x94,0x25,0x12,0x60,0x1d,0xa3,0xf9,0xef,0x45,0xe9,0xe8,0x36,0xc8,0x1a,0xdc,
  0x53,0xd7,0x37,0x80,0xd6,0x13,0x61,0x6a,0x52,0x22,0xf5,0x26,0x28,0xd6,0x97,0x88,
  0xef,0x14,0x92,0xb3,0x89,0x71,0x6,0xb9,0xc5,0x73,0x30,0xfb,0x9b,0xb2,0x15,0xa4,
  0x58,0xb,0x28,0x2b,0xea,0x19,0x4c,0xde,0x17,0x32,0xd2,0x46,0xd4,0x38,0xf2,0xc,
  0x51,0x8a,0x26,0xf4,0x8e,0x83,0x4c,0xd4,0x1e,0x79,0x7e,0x94,0x22,0xf,0xbd,0xd3,
  0x20,0x13,0xb1,0x47,0x9e,0x1f,0xa5,0xc8,0x43,0xef,0x30,0xc8,0x44,0xef,0x91,0x47,
  0x8f,0x52,0xc4,0x82,0xca,0x91,0xe4,0x31,0x51,0x5d,0x30,0x33,0xe7,0x48,0xef,0x21,
  0x98,0xdc,0x16,0xc6,0xbc,0x4e,0x19,0x60,0xac,0x83,0x2c,0x73,0x7,0x57,0x18,0x9a,
  0x2b,0x21,0x50,0x63,0x2c,0x1c,0x64,0x8c,0x4a,0x54,0x75,0x22,0x70,0x1b,0x65,0x9c,
  0xbe,0x8b,0x95,0x98,0x93,0x91,0x57,0x24,0x7f,0xdb,0xc1,0xf,0xe5,0x4e,0x49,0xdf,
  0xe7,0x2b,0x24,0xd2,0x90,0x36,0x9c,0x22,0xd6,0xd1,0x29,0xa5,0xfe,0xee,0x97,0x3a,
  0xa5,0x9e,0x84,0xac,0x76,0xec,0x34,0x76,0x7d,0x96,0x3c,0xa3,0x2d,0xc3,0x6,0xde,
  0xa8,0x8a,0xc9,0xc2,0x70,0xe4,0x6e,0xf3,0x7d,0x3d,0x3f,0x82,0xd2,0x86,0x95,0x49,
  0x5c,0x88,0x45,0xc8,0xe2,0x3a,0x86,0x52,0x2d,0x20,0x30,0x53,0x3e,0xe4,0x66,0x32,
  0x5f,0xd2,0x9,0x1e,0x22,0xde,0xc3,0x11,0x51,0x43,0xe2,0x2a,
  
};

static const unsigned char qt_resource_name[] = {
  // qt-project.org
  0x0,0xe,
  0x5,0x28,0x6c,0x87,
  0x0,0x71,
  0x0,0x74,0x0,0x2d,0x0,0x70,0x0,0x72,0x0,0x6f,0x0,0x6a,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x2e,0x0,0x6f,0x0,0x72,0x0,0x67,
    // brushes
  0x0,0x7,
  0x9,0x9c,0x9e,0x3,
  0x0,0x62,
  0x0,0x72,0x0,0x75,0x0,0x73,0x0,0x68,0x0,0x65,0x0,0x73,
    // defaultbrushes.xml
  0x0,0x12,
  0x3,0x3a,0x45,0x3c,
  0x0,0x64,
  0x0,0x65,0x0,0x66,0x0,0x61,0x0,0x75,0x0,0x6c,0x0,0x74,0x0,0x62,0x0,0x72,0x0,0x75,0x0,0x73,0x0,0x68,0x0,0x65,0x0,0x73,0x0,0x2e,0x0,0x78,0x0,0x6d,
  0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/brushes
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/brushes/defaultbrushes.xml
  0x0,0x0,0x0,0x36,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0xda,0x9a,0x35,0x90,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_formeditor1)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_formeditor1)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_formeditor1)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_formeditor1)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_formeditor1)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_formeditor1)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
